@@ -1,5 +1,5 @@
 package HackaMol;
-$HackaMol::VERSION = '0.017';
+$HackaMol::VERSION = '0.019';
 #ABSTRACT: HackaMol: Object-Oriented Library for Molecular Hacking
 use 5.008;
 use Moose;
@@ -14,22 +14,34 @@ use MooseX::StrictConstructor;
 use Scalar::Util qw(refaddr);
 use Carp;
 
-with 'HackaMol::NameRole', 'HackaMol::MolReadRole', 
-     'HackaMol::PathRole','HackaMol::ExeRole', 'HackaMol::FileFetchRole';
+with 'HackaMol::Roles::NameRole', 
+     'HackaMol::Roles::MolReadRole', 
+     'HackaMol::Roles::PathRole',
+     'HackaMol::Roles::ExeRole', 
+     'HackaMol::Roles::FileFetchRole';
 
+sub pdbid_mol {
+  my $self  = shift;
+  my $pdbid = shift || croak "pass pdbid";
+  my ($file,$rc) = $self->getstore_pdbid($pdbid);
+  return($self->read_file_mol($file));
+}
 
-sub read_file_append_mol{
+sub read_file_push_coords_mol{
     my $self = shift;
     my $file = shift;
     my $mol  = shift or croak "must pass molecule to add coords to";
 
     my @atoms = $self->read_file_atoms($file);
     my @matoms= $mol->all_atoms;
-    unless (scalar(@matoms) == scalar(@atoms) ){
-     # croak "number of atoms not same";
+
+    if (scalar(@matoms) != scalar(@atoms) ){
+      croak "file_push_coords_mol> number of atoms not same";
     }
     foreach my $i (0 .. $#atoms) {
-     # croak "atom mismatch" unless ($matoms[$i]->Z == $atoms[$i]->Z); 
+      if ($matoms[$i]->Z != $atoms[$i]->Z){
+        croak "file_push_coords_mol> atom mismatch";
+      }
       $matoms[$i]->push_coords($_) foreach ($atoms[$i]->all_coords);
     }
 }
@@ -48,7 +60,7 @@ sub build_bonds {
     #take a list of n, atoms; walk down list and generate bonds
     my $self  = shift;
     my @atoms = @_;
-    croak "<2 atoms passed to build_dihedrals" unless ( @atoms > 1 );
+    croak "<2 atoms passed to build_bonds" unless ( @atoms > 1 );
     my @bonds;
     # build the bonds
     my $k = 0;
@@ -70,7 +82,7 @@ sub build_angles {
     #take a list of n, atoms; walk down list and generate angles
     my $self  = shift;
     my @atoms = @_;
-    croak "<3 atoms passed to build_dihedrals" unless ( @atoms > 2 );
+    croak "<3 atoms passed to build_angles" unless ( @atoms > 2 );
     my @angles;
 
     # build the angles
@@ -219,84 +231,65 @@ HackaMol - HackaMol: Object-Oriented Library for Molecular Hacking
 
 =head1 VERSION
 
-version 0.017
-
-=head1 SYNOPSIS
-
-       use HackaMol;
-       use Math::Vector::Real;
-
-       my $hack = HackaMol->new( name => "hackitup" );
-
-       # all coordinates from NMR ensemble are loaded into atoms
-       my $mol  = $hack->read_file_mol("1L2Y.pdb");
-
-       #recenter all coordinates to center of mass
-       foreach my $t ( 0 .. $mol->tmax) {
-           $mol->t($t);
-           $mol->translate( -$mol->COM );
-       }
-
-       #create array of CA atoms with full occupancy
-
-       my @CAs = grep {
-                        $_->name    eq 'CA'  and
-                        $_->occ == 1
-                      } $mol->all_atoms;
-
-       #print out the pdb with CA for several models from the NMR
-       HackaMol::Molecule->new(
-                                atoms=>[@CAs]
-                              )-> print_pdb_ts([8,2,4,6,8,0], 'some.pdb');
-
-       # print coordinates to trp-cage.xyz and return filehandle for future
-       # writing
-       my $fh = $mol->print_xyz( $mol->name . ".xyz" );
-       foreach ( 1 .. 10 ) {
-           $mol->rotate(
-               V( 0, 0, 1 ),    # rotation vector
-               36,              # rotate by 36 degrees
-               V( 5, 0, 0 )     # origin of rotation
-           );
-           $mol->print_xyz($fh);
-       }
-
-       # translate/rotate method is provided by AtomGroupRole
-       # populate groups byatom resid attr
-       my @groups = $hack->group_by_atom_attr( 'resid', $mol->all_atoms );
-       $mol->push_groups(@groups);
-
-       foreach my $ang ( 1 .. 10 ) {
-           $_->rotate( V( 1, 1, 1 ), 36, $_->COM ) foreach $mol->all_groups;
-           $mol->print_xyz($fh);
-       }
+version 0.019
 
 =head1 DESCRIPTION
 
-The HackaMol library simplifies powerful scripting of multiscale molecular modeling and analysis. HackaMol seeks to 
-provide intuitive attributes and methods that may be harnessed to coerce molecular computation through a common core. 
-The library is inspired by L<PerlMol|http://www.perl.org>, L<BioPerl|http://bioperl.org>, L<MMTSB|http://www.mmtsb.org>, 
-and our own experiences as researchers. 
+The L<HackaMol publication | http://pubs.acs.org/doi/abs/10.1021/ci500359e> has
+a more complete description of the library (L<pdf available from researchgate| http://www.researchgate.net/profile/Demian_Riccardi/publication/273778191_HackaMol_an_object-oriented_Modern_Perl_library_for_molecular_hacking_on_multiple_scales/links/550ebec60cf27526109e6ade.pdf>). 
 
-The library is organized into two regions: HackaMol, the core (contained here)
-that has classes for atoms and molecules, and HackaMol::X, the extensions, such as
-HackaMol::X::Vina (an interface to Autodock Vina) or HackaMol::X::Calculator,
-a more general abstract calculator for interfacing external programs. The three major goals of the core are for it to 
-be well-tested, well-documented, and easy to install. The goal of the extensions is to provide a more flexible space 
-for researchers to develop and share new methods that use the core.  
+Citation: J. Chem. Inf. Model., 2015, 55, 721 
 
-HackaMol uses Math::Vector::Real (MVR) for all the vector operations. The methods of MVR overlap very well with those
-needed for working with atoms and coarse grained molecules. MVR is a lightweight solution with an XS drop-in that makes 
-vector analyses very fast. Extensions that treat much larger systems will definitely benefit from the capabilities of L<PDL>.
+Loading the HackaMol library in a script with 
 
-The HackaMol class (loaded in Synopsis) uses the core classes to provide some object 
-building utilities described below.  This class consumes HackaMol::MolReadRole to 
-provide structure readers for xyz and pdb coordinates.  
-See L<Open Babel|http://openbabel.org> if other formats needed 
-(All suggestions, contributions welcome!).  
+       use HackaMol;
+
+provides attributes and methods of a builder class. It also loads all the 
+classes provided by the core so including them is not necessary, e.g.:
+
+       use HackaMol::Atom;
+       use HackaMol::Bond;
+       use HackaMol::Angle;
+       use HackaMol::Dihedral;
+       use HackaMol::AtomGroup;
+       use HackaMol::Molecule;
+
+The methods, described below, facilitate the creation of objects from files and
+other objects.
 
 =head1 METHODS
 
+=head2 pdbid_mol
+
+one argument: pdbid
+
+This method will download the pdb, unless it exists, and load it into a 
+HackaMol::Molecule object. For example,
+
+      my $mol = HackaMol->new->pdbid_mol('2cba');
+
+=head2 read_file_atoms
+
+one argument: filename.
+
+This method parses the file (e.g. file.xyz, file.pdb) and returns an 
+array of HackaMol::Atom objects.
+
+=head2 read_file_mol
+
+one argument: filename.
+
+This method parses the file (e.g. file.xyz, file.pdb) and returns a 
+HackaMol::Molecule object.
+
+=head2 read_file_push_coords_mol
+
+two arguments: filename and a HackaMol::Molecule object. 
+
+This method reads the coordinates from a file and pushes them into the atoms 
+contained in the molecule. Thus, the atoms in the molecule and the atoms in 
+the file must be the same.
+
 =head2 build_bonds
 
 takes a list of atoms and returns a list of bonds.  The bonds are generated for
@@ -330,13 +323,16 @@ will return two dihedrals: D1356 and D3569
 
 =head2 group_by_atom_attr
 
-takes atom attribute and a list of atoms as arguments and builds AtomGroup objects by attribute.
-Grouping by graphical searches are needed! 
+arguments are an atom attribute and then a list of atoms. 
+
+This method builds AtomGroup objects that are grouped by attribute.
 
 =head2 find_bonds_brute 
 
-takes hash argument list and returns bonds.  Find bonds between bond_atoms and 
-the candidates.
+The arguments are key_value pairs of bonding criteria (see example below). 
+
+This method returns bonds between bond_atoms and the candidates using the 
+criteria (many of wich have defaults).
 
   my @oxy_bonds = $hack->find_bonds_brute(
                                     bond_atoms => [$hg],
@@ -357,7 +353,9 @@ a self bond for an atom (C< next if refaddr($ati) == refaddr($atj) >).
 
 =head2 find_disulfide_bonds
 
-takes a list of atoms and returns the disulfide bonds as bond objects.
+the argument is a list of atoms, e.g. '($mol->all_atoms)'. 
+
+this method returns disulfide bonds as bond objects.
 
 =head1 ATTRIBUTES
 
@@ -365,6 +363,21 @@ takes a list of atoms and returns the disulfide bonds as bond objects.
 
 name is a rw str provided by HackaMol::NameRole.
 
+=head1 SYNOPSIS 
+
+       # simple example: load pdb file and extract the disulfide bonds
+
+       use HackaMol;
+
+       my $bldr = HackaMol->new( name => 'builder');
+       my $mol  = $bldr->pdbid_mol('1kni');
+
+       my @disulfide_bonds = $bldr->find_disulfide_bonds( $mol->all_atoms );
+
+       print $_->dump foreach @disulfide_bonds;
+
+See the above executed in this L<linked notebook | https://github.com/demianriccardi/p5-IPerl-Notebooks/blob/master/HackaMol/HackaMol-Synopsis.ipynb>
+
 =head1 SEE ALSO
 
 =over 4
@@ -423,17 +436,29 @@ L<VMD | http://www.ks.uiuc.edu/Research/vmd/>
 
 =over 4
 
-=item * L<HackaMol::ExeRole>
+=item * L<HackaMol::Roles::ExeRole>
 
-=item * L<HackaMol::FileFetchRole>
+=item * L<HackaMol::Roles::FileFetchRole>
 
-=item * L<HackaMol::MolReadRole>
+=item * L<HackaMol::Roles::MolReadRole>
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::NERFRole>
 
-=item * L<HackaMol::NameRole|HackaMol::MolReadRole|HackaMol::PathRole|HackaMol::ExeRole|HackaMol::FileFetchRole>
+=item * L<HackaMol::Roles::NameRole>
 
-=item * L<HackaMol::PathRole>
+=item * L<HackaMol::Roles::NameRole|HackaMol::Roles::MolReadRole|HackaMol::Roles::PathRole|HackaMol::Roles::ExeRole|HackaMol::Roles::FileFetchRole>
+
+=item * L<HackaMol::Roles::PathRole>
+
+=item * L<HackaMol::Roles::ReadPdbRole>
+
+=item * L<HackaMol::Roles::ReadPdbqtRole>
+
+=item * L<HackaMol::Roles::ReadXyzRole>
+
+=item * L<HackaMol::Roles::ReadZmatRole>
+
+=item * L<HackaMol::Roles::ReadZmatRole|HackaMol::Roles::ReadPdbRole|HackaMol::Roles::ReadPdbqtRole|HackaMol::Roles::ReadXyzRole>
 
 =back
 
