@@ -1,5 +1,5 @@
 package HackaMol::AtomGroupRole;
-$HackaMol::AtomGroupRole::VERSION = '0.017';
+
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -312,13 +312,8 @@ sub _open_file_unless_fh {
     my $fh = \*STDOUT;   # default to standard out
                          # if argument is passed, check if filehandle
     if ( defined($file) ) {
-        if ( ref($file) ) {
-            if (reftype($file) eq "GLOB"){
-              $fh = $file;
-            }
-            else {
-              croak "trying write to reference that is not a GLOB";
-            }
+        if ( ref($file) and reftype($file) eq "GLOB" ) {
+            $fh = $file;
         }
         else {
             carp "overwrite $file" if ( -e $file );
@@ -344,7 +339,7 @@ HackaMol::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.017
+version 0.011
 
 =head1 SYNOPSIS
 
