@@ -1,5 +1,5 @@
 package HackaMol::Bond;
-$HackaMol::Bond::VERSION = '0.017';
+$HackaMol::Bond::VERSION = '0.019';
 #ABSTRACT: HackaMol Bond class
 use 5.008;
 use Moose;
@@ -8,7 +8,7 @@ use Carp;
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ), 
-with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
+with 'HackaMol::Roles::NameRole', 'HackaMol::Roles::AtomGroupRole';
 
 has $_ => (
     is      => 'rw',
@@ -76,7 +76,7 @@ HackaMol::Bond - HackaMol Bond class
 
 =head1 VERSION
 
-version 0.017
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -230,11 +230,11 @@ L<Chemistry::Bond>
 
 =over 4
 
-=item * L<HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::AtomGroupRole>
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::NameRole>
 
-=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::NameRole|HackaMol::Roles::AtomGroupRole>
 
 =back
 
