@@ -1,5 +1,5 @@
 package HackaMol::Dihedral;
-$HackaMol::Dihedral::VERSION = '0.017';
+$HackaMol::Dihedral::VERSION = '0.019';
 #ABSTRACT: Dihedral Angle class for HackaMol
 use 5.008;
 use Moose;
@@ -9,7 +9,7 @@ use Math::Trig;
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ), 
-with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
+with 'HackaMol::Roles::NameRole', 'HackaMol::Roles::AtomGroupRole';
 
 has $_ => (
     is      => 'rw',
@@ -92,7 +92,7 @@ HackaMol::Dihedral - Dihedral Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.017
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -239,11 +239,11 @@ L<HackaMol::Angle>
 
 =over 4
 
-=item * L<HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::AtomGroupRole>
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::NameRole>
 
-=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::NameRole|HackaMol::Roles::AtomGroupRole>
 
 =back
 
