@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.017';
+$HackaMol::Molecule::VERSION = '0.018';
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -10,8 +10,9 @@ use Scalar::Util qw(refaddr);
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ), 
-with 'HackaMol::NameRole', 'HackaMol::PhysVecMVRRole',
-  'HackaMol::BondsAnglesDihedralsRole', 'HackaMol::QmMolRole';
+with 'HackaMol::Roles::PhysVecMVRRole',
+     'HackaMol::Roles::BondsAnglesDihedralsRole', 
+     'HackaMol::Roles::QmMolRole';
 
 extends 'HackaMol::AtomGroup';
 
@@ -217,7 +218,7 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -405,17 +406,15 @@ L<Chemistry::Molecule>
 
 =over 4
 
-=item * L<HackaMol::BondsAnglesDihedralsRole>
+=item * L<HackaMol::Roles::BondsAnglesDihedralsRole>
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::PhysVecMVRRole>
 
-=item * L<HackaMol::NameRole|HackaMol::PhysVecMVRRole|HackaMol::BondsAnglesDihedralsRole|HackaMol::QmMolRole>
+=item * L<HackaMol::Roles::PhysVecMVRRole|HackaMol::Roles::BondsAnglesDihedralsRole|HackaMol::Roles::QmMolRole>
 
-=item * L<HackaMol::PhysVecMVRRole>
+=item * L<HackaMol::Roles::QmAtomRole>
 
-=item * L<HackaMol::QmAtomRole>
-
-=item * L<HackaMol::QmMolRole>
+=item * L<HackaMol::Roles::QmMolRole>
 
 =back
 
